@@ -967,6 +967,36 @@ protected:
         PMOS_RESOURCE             vdencBrcImgBuffer,
         PMHW_VDBOX_AVC_IMG_PARAMS params);
 
+    //!
+    //! \brief    Get Encode Status for Vulkan Query Pool
+    //! \details  Retrieve the necessary status and results for the Vulkan query pool 
+    //!           from the status buffer, such as bitstream size, hardware encoding status, bitstream offset
+    //! \param    [in] queryFrameIndex
+    //!               The specified frame index
+    //!           [in] pData
+    //!               Points to the buffer passed by Vulkan for storing the results.
+    //!           [in] dataOffset
+    //!               Starting position for writing to pData
+    //!           [in] is64bit
+    //!               Whether each result is 64-bit, otherwise 32-bit.
+    //!           [in] reportStatus
+    //!               Whether the encode status needs to be returned
+    //!           [in] reportOffset
+    //!               Whether the bitstream offset needs to be returned
+    //!           [in] reportBitstream
+    //!               Whether the bitstream size needs to be returned
+    //! \return   MOS_STATUS
+    //!           MOS_STATUS_SUCCESS if success, else fail reason
+    //!
+    virtual MOS_STATUS GetVulkanQueryPoolResults(
+        uint32_t queryFrameIndex,
+        void    *pData,
+        uint64_t dataOffset,
+        bool     is64bit,
+        uint8_t  reportStatus,
+        bool     reportOffset,
+        bool     reportBitstream) override;
+
     //!
     //! \brief    Report Slice Size to MetaData buffer
     //! \details  Report Slice Size to MetaData buffer.
@@ -1301,7 +1331,13 @@ MOS_STATUS CodechalVdencAvcState::SetDmemHuCBrcInitResetImpl(CODECHAL_VDENC_AVC_
         avcSeqParams, this, &profileLevelMaxFrame));
 
     hucVDEncBrcInitDmem->INIT_ProfileLevelMaxFrame_U32 = profileLevelMaxFrame;
-    if (avcSeqParams->GopRefDist && (avcSeqParams->GopPicSize > 0))
+
+    if (avcSeqParams->GopRefDist >= avcSeqParams->GopPicSize && avcSeqParams->GopPicSize > 1)
+    {
+        hucVDEncBrcInitDmem->INIT_GopP_U16 = 1;
+        hucVDEncBrcInitDmem->INIT_GopB_U16 = avcSeqParams->GopPicSize - 2;
+    }
+    else if (avcSeqParams->GopRefDist && (avcSeqParams->GopPicSize > 0))
     {
         // Their ratio is used in BRC kernel to detect mini GOP structure. Have to be multiple.
         hucVDEncBrcInitDmem->INIT_GopP_U16 = (avcSeqParams->GopPicSize - 1) / avcSeqParams->GopRefDist;
