@@ -56,6 +56,7 @@ MOS_STATUS MhwMiInterfaceG11::AddMiBatchBufferStartCmd(
 {
     MHW_FUNCTION_ENTER;
 
+    MHW_MI_CHK_NULL(m_osInterface);
     MHW_MI_CHK_NULL(cmdBuffer);
     MHW_MI_CHK_NULL(batchBuffer);
 
@@ -83,7 +84,7 @@ MOS_STATUS MhwMiInterfaceG11::AddMiBatchBufferStartCmd(
     cmd.DW0.AddressSpaceIndicator = !IsGlobalGttInUse();
 
     // Send BB start command
-    MHW_MI_CHK_STATUS(Mos_AddCommand(cmdBuffer, &cmd, cmd.byteSize));
+    MHW_MI_CHK_STATUS(m_osInterface->pfnAddCommand(cmdBuffer, &cmd, cmd.byteSize));
 
     return MOS_STATUS_SUCCESS;
 }
@@ -94,6 +95,7 @@ MOS_STATUS MhwMiInterfaceG11::AddMiConditionalBatchBufferEndCmd(
 {
     MHW_FUNCTION_ENTER;
 
+    MHW_MI_CHK_NULL(m_osInterface);
     MHW_MI_CHK_NULL(cmdBuffer);
     MHW_MI_CHK_NULL(params);
     MHW_MI_CHK_NULL(params->presSemaphoreBuffer);
@@ -125,7 +127,7 @@ MOS_STATUS MhwMiInterfaceG11::AddMiConditionalBatchBufferEndCmd(
         &resourceParams));
 
     // Send Conditional Batch Buffer End command
-    MHW_MI_CHK_STATUS(Mos_AddCommand(cmdBuffer, &cmd, cmd.byteSize));
+    MHW_MI_CHK_STATUS(m_osInterface->pfnAddCommand(cmdBuffer, &cmd, cmd.byteSize));
 
     //Re-enable CP for Case 2
     MHW_MI_CHK_STATUS(m_cpInterface->AddProlog(m_osInterface, cmdBuffer));
@@ -276,21 +278,7 @@ MOS_STATUS MhwMiInterfaceG11::SetWatchdogTimerThreshold(uint32_t frameWidth, uin
         }
     }
 
-    MOS_USER_FEATURE_VALUE_DATA userFeatureData;
-    MOS_ZeroMemory(&userFeatureData, sizeof(userFeatureData));
-#if (_DEBUG || _RELEASE_INTERNAL)
-    // User feature config of watchdog timer threshold
-    MOS_ZeroMemory(&userFeatureData, sizeof(userFeatureData));
-    MOS_UserFeature_ReadValue_ID(
-        nullptr,
-        __MEDIA_USER_FEATURE_VALUE_MEDIA_RESET_TH_ID,
-        &userFeatureData,
-        m_osInterface->pOsContext);
-    if (userFeatureData.u32Data != 0)
-    {
-        MediaResetParam.watchdogCountThreshold = userFeatureData.u32Data;
-    }
-#endif
+    GetWatchdogThreshold(m_osInterface);
 
     return MOS_STATUS_SUCCESS;
 }
@@ -446,7 +434,7 @@ MOS_STATUS MhwMiInterfaceG11::AddMediaStateFlush(
         cmd.DW1.InterfaceDescriptorOffset = params->ui8InterfaceDescriptorOffset;
     }
 
-    MHW_MI_CHK_STATUS(Mhw_AddCommandCmdOrBB(cmdBuffer, batchBuffer, &cmd, cmd.byteSize));
+    MHW_MI_CHK_STATUS(Mhw_AddCommandCmdOrBB(m_osInterface, cmdBuffer, batchBuffer, &cmd, cmd.byteSize));
 
 #if (_DEBUG || _RELEASE_INTERNAL)
     if (batchBuffer)
@@ -497,6 +485,7 @@ MOS_STATUS MhwMiInterfaceG11::AddMiFlushDwCmd(
 {
     MHW_FUNCTION_ENTER;
 
+    MHW_MI_CHK_NULL(m_osInterface);
     MHW_MI_CHK_STATUS(MhwMiInterfaceGeneric<mhw_mi_g11_X>::AddMiFlushDwCmd(cmdBuffer, params));
 
     mhw_mi_g11_X::MI_FLUSH_DW_CMD cmd;
@@ -543,7 +532,7 @@ MOS_STATUS MhwMiInterfaceG11::AddMiFlushDwCmd(
         cmd.DW0.DwordLength--;
     }
 
-    MHW_MI_CHK_STATUS(Mos_AddCommand(cmdBuffer, &cmd, cmd.byteSize));
+    MHW_MI_CHK_STATUS(m_osInterface->pfnAddCommand(cmdBuffer, &cmd, cmd.byteSize));
 
     return MOS_STATUS_SUCCESS;
 }
\ No newline at end of file
