@@ -59,7 +59,7 @@ static MOS_STATUS CodecHalDecodeScalability_CalculateScdryCmdBufIndex_G12(
     {
         *pdwBufIdxPlus1 = pScalabilityState->u8RtCurPipe + 1;
         if(pScalabilityStateBase->pHwInterface->GetOsInterface()->phasedSubmission
-        && !pScalabilityStateBase->pHwInterface->GetOsInterface()->bGucSubmission)
+        && !pScalabilityStateBase->pHwInterface->GetOsInterface()->bParallelSubmission)
         {
             /*  3 tiles 2 pipe for example:
                 cur phase               cur pip
@@ -253,7 +253,7 @@ MOS_STATUS CodecHalDecodeScalability_GetCmdBufferToUse_G12(
 
     if (!CodecHalDecodeScalabilityIsFESeparateSubmission(pScalabilityState) ||
         CodecHalDecodeScalabilityIsBEPhaseG12(pScalabilityState) ||
-        pScalabilityStateBase->pHwInterface->GetOsInterface()->bGucSubmission)
+        pScalabilityStateBase->pHwInterface->GetOsInterface()->bParallelSubmission)
     {
         pScalabilityState->bUseSecdryCmdBuffer = true;
         CODECHAL_DECODE_CHK_STATUS(CodecHalDecodeScalability_GetVESecondaryCmdBuffer_G12(pScalabilityState, pScdryCmdBuf));
@@ -516,6 +516,7 @@ MOS_STATUS CodecHalDecodeScalability_InitScalableParams_G12(
         bCanEnableRealTile = bCanEnableRealTile && pInitParams->bIsTileEnabled && (pInitParams->u8NumTileColumns > 1) &&
             (pInitParams->u8NumTileColumns <= u8MaxTileColumn) && (pInitParams->u8NumTileRows <= HEVC_NUM_MAX_TILE_ROW) &&
             pInitParams->bHasSubsetParams;
+        
         if (bCanEnableRealTile)
         {
             pScalabilityState->bIsRtMode = true;
@@ -699,7 +700,7 @@ MOS_STATUS CodecHalDecodeScalability_FEBESync_G12(
     //FE& BE0 Sync. to refine (ucNumVdbox > )for GT3
     if (HcpDecPhase == CODECHAL_HCP_DECODE_PHASE_BE0
         && pScalabilityState->pHwInterface->GetMfxInterface()->GetNumVdbox() > 2
-        && !pOsInterface->bGucSubmission)
+        && !pOsInterface->bParallelSubmission)
     {
         if (pScalabilityState->bFESeparateSubmission)
         {
@@ -894,6 +895,7 @@ MOS_STATUS CodecHalDecodeScalability_ReadCSEngineIDReg_G12(
         pDecodeStatusBuf->m_csEngineIdOffset + sizeof(uint32_t)* ucPhaseIndex +
         sizeof(uint32_t) * 2;
 
+    MOS_ZeroMemory(&StoreRegParams, sizeof(StoreRegParams));
     StoreRegParams.presStoreBuffer = &pDecodeStatusBuf->m_statusBuffer;
     StoreRegParams.dwOffset = dwOffset;
     StoreRegParams.dwRegister = pMmioRegisters->csEngineIdOffset;
@@ -1018,7 +1020,7 @@ MOS_STATUS CodecHalDecodeScalability_InitializeState_G12(
         pScalabilityState->bFESeparateSubmission = false;
     }
 
-    if(osInterface->bGucSubmission)
+    if(osInterface->bParallelSubmission)
     {
         pScalabilityState->bFESeparateSubmission = false;
     }
@@ -1326,7 +1328,8 @@ MOS_STATUS CodecHalDecodeScalability_SetSfcState(
     if (tileColumnIndex == 0)
     {
         scalabilityState->fistValidTileIndex = 0;
-        scalabilityState->lastValidTileIndex = tileColumnCount - 1;
+        CODECHAL_DECODE_CHK_COND_RETURN(tileColumnCount == 0,"tileColumnCount minmum value should be 1");
+        scalabilityState->lastValidTileIndex = tileColumnCount - 1;                
         scalabilityState->dstXLandingCount = 0;
     }
 
@@ -1365,7 +1368,7 @@ MOS_STATUS CodecHalDecodeScalability_SetSfcState(
         {
             const uint32_t one_by_sf_fraction_precision = 19;
             const uint32_t beta_precision = 5;
-            uint32_t xPhaseShift = MOS_CLAMP_MIN_MAX(MOS_F_ROUND((((double)srcRegion->m_width / dstRegion->m_width - 1.0) / 2.0) * 524288.0F), -(1 << (4 + 19)), ((1 << (4 + 19)) - 1));
+            double xPhaseShift = MOS_CLAMP_MIN_MAX(MOS_F_ROUND((((double)srcRegion->m_width / dstRegion->m_width - 1.0) / 2.0) * 524288.0F), -(1 << (4 + 19)), ((1 << (4 + 19)) - 1));
 
             double tempDestCntx = (((double)scalabilityState->dstXLandingCount * (double)oneBySf) + xPhaseShift);
             if (tempDestCntx < 0)
@@ -1377,8 +1380,16 @@ MOS_STATUS CodecHalDecodeScalability_SetSfcState(
 
         if (xLandingPoint >= (double)(tileEndX - xOffset))
         {
-            dstEndX = scalabilityState->dstXLandingCount - 1;
-            break;
+            if(scalabilityState->dstXLandingCount >= 1)
+            {
+                dstEndX = scalabilityState->dstXLandingCount - 1;
+                break;
+            }
+            else
+            {
+                CODECHAL_DECODE_ASSERTMESSAGE("Invalid dstXLandingCount in this condition"); //scalabilityState->dstXLandingCount- 1 should not < 0 at this condition
+                return MOS_STATUS_INVALID_PARAMETER;
+            }
         }
         else
         {
@@ -1460,7 +1471,7 @@ MOS_STATUS CodecHalDecodeScalability_AllocateResources_VariableSizes_G12(
     // for multi-pipe scalability mode
     if (pScalabilityState->ucNumVdbox > 2)
     {
-        if (pScalabilityState->bFESeparateSubmission && pOsInterface->bGucSubmission)
+        if (pScalabilityState->bFESeparateSubmission && pOsInterface->bParallelSubmission)
         {
             for (int i = 1; i < CODECHAL_HCP_STREAMOUT_BUFFER_MAX_NUM; i++)
             {
@@ -1587,6 +1598,11 @@ bool CodecHalDecodeScalability_DecideEnableScala_G12(
     {
         bEnableScala = true;
     }
+    else if(MEDIA_IS_SKU(pScalState->pHwInterface->GetSkuTable(), FtrVirtualTileScalabilityDisable))
+    {
+        bEnableScala = false;
+        CODECHAL_DECODE_NORMALMESSAGE(" Disable VT Scalability according to platform SKU");
+    }
     else
     {
         // NonRextFormat && >=5k - VT Scalability
@@ -1980,7 +1996,7 @@ void CodecHalDecodeScalability_DecPhaseToSubmissionType_G12(
                 pCmdBuffer->iSubmissionType |= ((pScalabilityState->u8RtCurPipe - 1) << SUBMISSION_TYPE_MULTI_PIPE_SLAVE_INDEX_SHIFT);
             }
 
-            if (!(pScalabilityState->pHwInterface->GetOsInterface()->bGucSubmission)
+            if (!(pScalabilityState->pHwInterface->GetOsInterface()->bParallelSubmission)
             && (pScalabilityState->u8RtCurPhase == pScalabilityState->u8RtPhaseNum - 1))
             {
                 if (pScalabilityState->u8RtCurPipe == pScalabilityState->u8RtPipeInLastPhase - 1)
