@@ -62,7 +62,6 @@ public:
     virtual MOS_STATUS VeboxQueryStatLayout(
         VEBOX_STAT_QUERY_TYPE queryType,
         uint32_t* pQuery);
-    virtual VpKernelConfig &GetKernelConfig();
 
     virtual uint32_t VeboxQueryStaticSurfaceSize()
     {
@@ -84,6 +83,11 @@ public:
         return false;
     }
 
+    virtual bool IsLegacyEuCountInUse()
+    {
+        return true;
+    }
+
     virtual MOS_STATUS GetInputFrameWidthHeightAlignUnit(
         PVP_MHWINTERFACE          pvpMhwInterface,
         uint32_t                 &widthAlignUnit,
