@@ -254,6 +254,12 @@ MOS_STATUS HevcPipelineXe2_Lpm_Base::Prepare(void *params)
             inputParameters.numUsedVdbox               = m_numVdbox;
             inputParameters.numSlices                  = m_basicFeature->m_numSlices;
             inputParameters.currDecodedPicRes          = m_basicFeature->m_destSurface.OsResource;
+
+            CODECHAL_DEBUG_TOOL(
+                if (m_streamout != nullptr) {
+                    DECODE_CHK_STATUS(m_streamout->InitStatusReportParam(inputParameters));
+                });
+
 #if (_DEBUG || _RELEASE_INTERNAL)
 #ifdef _DECODE_PROCESSING_SUPPORTED
             DecodeDownSamplingFeature* downSamplingFeature = dynamic_cast<DecodeDownSamplingFeature*>(
@@ -303,12 +309,11 @@ MOS_STATUS HevcPipelineXe2_Lpm_Base::Execute()
 
 #if (_DEBUG || _RELEASE_INTERNAL)
             DECODE_CHK_STATUS(StatusCheck());
-#ifdef _MMC_SUPPORTED
+
             if (m_mmcState != nullptr)
             {
                 m_mmcState->ReportSurfaceMmcMode(&(m_basicFeature->m_destSurface));
             }
-#endif
 #endif
 
             // Recover RefList for SCC IBC mode
@@ -359,9 +364,8 @@ MOS_STATUS HevcPipelineXe2_Lpm_Base::Initialize(void *settings)
 {
     DECODE_FUNC_CALL();
     DECODE_CHK_STATUS(HevcPipeline::Initialize(settings));
-#ifdef _MMC_SUPPORTED
+
     DECODE_CHK_STATUS(InitMmcState());
-#endif
 
     return MOS_STATUS_SUCCESS;
 }
@@ -394,12 +398,10 @@ MOS_STATUS HevcPipelineXe2_Lpm_Base::Uninitialize()
         pair.second->Destroy();
     }
 
-#ifdef _MMC_SUPPORTED
     if (m_mmcState != nullptr)
     {
         MOS_Delete(m_mmcState);
     }
-#endif
 
     return HevcPipeline::Uninitialize();
 }
@@ -452,7 +454,6 @@ MOS_STATUS HevcPipelineXe2_Lpm_Base::CreateSubPackets(DecodeSubPacketManager& su
     return MOS_STATUS_SUCCESS;
 }
 
-#ifdef _MMC_SUPPORTED
 MOS_STATUS HevcPipelineXe2_Lpm_Base::InitMmcState()
 {
     DECODE_FUNC_CALL();
@@ -463,7 +464,6 @@ MOS_STATUS HevcPipelineXe2_Lpm_Base::InitMmcState()
     DECODE_CHK_STATUS(m_basicFeature->SetMmcState(m_mmcState->IsMmcEnabled()));
     return MOS_STATUS_SUCCESS;
 }
-#endif
 
 #if USE_CODECHAL_DEBUG_TOOL
 MOS_STATUS HevcPipelineXe2_Lpm_Base::DumpParams(HevcBasicFeature &basicFeature)
