@@ -50,7 +50,7 @@ public:
     //!         Pointer to CodechalDebugInterface
     //!
     Vp9Pipeline(
-        CodechalHwInterface *   hwInterface,
+        CodechalHwInterfaceNext *hwInterface,
         CodechalDebugInterface *debugInterface);
 
     virtual ~Vp9Pipeline() {};
@@ -68,6 +68,7 @@ public:
     DeclareDecodePacketId(vp9PictureSubPacketId);
     DeclareDecodePacketId(vp9SliceSubPacketId);
     DeclareDecodePacketId(vp9TileSubPacketId);
+    DeclareDecodePacketId(vp9DebugSubPacketId);
 
 protected:
     //!
@@ -195,6 +196,16 @@ protected:
     //!           MOS_STATUS_SUCCESS if success, else fail reason
     //!
     MOS_STATUS DumpSegmentParams(CODEC_VP9_SEGMENT_PARAMS *segmentParams);
+
+    //! \brief    Dump slice parameters into file
+    //!
+    //! \param    [in] slcParams
+    //!           Pointer to PCODEC_VP9_SLICE_PARAMS
+    //!
+    //! \return   MOS_STATUS
+    //!           MOS_STATUS_SUCCESS if success, else fail reason
+    //!
+    MOS_STATUS DumpSliceParams(CODEC_VP9_SLICE_PARAMS *slcParams);
 #endif
 
 protected:
@@ -209,7 +220,7 @@ protected:
     uint32_t m_vtFrameCount = 0; //!< frame count for virtual tile decoding
 #endif
 
-MEDIA_CLASS_DEFINE_END(Vp9Pipeline)
+MEDIA_CLASS_DEFINE_END(decode__Vp9Pipeline)
 };
 
 }
