@@ -42,6 +42,7 @@ static constexpr uint32_t MEMORY_ADDRESS_ATTRIBUTES_MOCS_CLEAN_MASK = 0xFFFFFF81
 static constexpr uint32_t HUC_UKERNEL_HDR_INFO_REG_OFFSET_NODE_1_INIT = 0x1C2014;
 static constexpr uint32_t HUC_STATUS_REG_OFFSET_NODE_1_INIT           = 0x1C2000;
 static constexpr uint32_t HUC_STATUS2_REG_OFFSET_NODE_1_INIT          = 0x1C23B0;
+static constexpr uint32_t HUC_LOAD_INFO_REG_OFFSET_NODE_1_INIT        = 0xC1DC;
 
 template <typename cmd_t>
 class Impl : public Itf, public mhw::Impl
@@ -69,8 +70,10 @@ public:
     //! \return   [out] MmioRegistersHuc*
     //!           mmio registers got.
     //!
-    HucMmioRegisters* GetMmioRegisters(MHW_VDBOX_NODE_IND index)
+    HucMmioRegisters* GetMmioRegisters(MHW_VDBOX_NODE_IND index) override
     {
+        MHW_FUNCTION_ENTER;
+
         if (index < MHW_VDBOX_NODE_MAX)
         {
             return &m_mmioRegisters[index];
@@ -85,26 +88,39 @@ public:
 private:
     void InitMmioRegisters()
     {
+        MHW_FUNCTION_ENTER;
+
         HucMmioRegisters *mmioRegisters = &m_mmioRegisters[MHW_VDBOX_NODE_1];
 
         mmioRegisters->hucUKernelHdrInfoRegOffset = HUC_UKERNEL_HDR_INFO_REG_OFFSET_NODE_1_INIT;
         mmioRegisters->hucStatusRegOffset         = HUC_STATUS_REG_OFFSET_NODE_1_INIT;
         mmioRegisters->hucStatus2RegOffset        = HUC_STATUS2_REG_OFFSET_NODE_1_INIT;
+        mmioRegisters->hucLoadInfoOffset          = HUC_LOAD_INFO_REG_OFFSET_NODE_1_INIT;
 
         m_mmioRegisters[MHW_VDBOX_NODE_2] = m_mmioRegisters[MHW_VDBOX_NODE_1];
     }
 
-    uint32_t GetHucStatusHevcS2lFailureMask()
+    uint32_t GetHucStatusReEncodeMask() override
+    {
+        return m_hucStatusReEncodeMask;
+    }
+
+    uint32_t GetHucStatusHevcS2lFailureMask() override
     {
         return m_hucStatusHevcS2lFailureMask;
     }
 
-    uint32_t GetHucStatus2ImemLoadedMask()
+    uint32_t GetHucStatus2ImemLoadedMask() override
     {
         return m_hucStatus2ImemLoadedMask;
     }
 
-    uint32_t GetHucProductFamily()
+    uint32_t GetHucErrorFlagsMask() override
+    {
+        return m_hucErrorFlagsMask;
+    }
+
+    uint32_t GetHucProductFamily() override
     {
         return m_hucFamily;
     }
@@ -113,8 +129,10 @@ protected:
     using base_t = Itf;
     HucMmioRegisters      m_mmioRegisters[MHW_VDBOX_NODE_MAX] = {};  //!< HuC mmio registers
     MhwCpInterface        *m_cpItf = nullptr;
+    static const uint32_t m_hucStatusReEncodeMask             = 0x80000000;
     static const uint32_t m_hucStatusHevcS2lFailureMask       = 0x8000;
     static const uint32_t m_hucStatus2ImemLoadedMask          = 0x40;
+    static const uint32_t m_hucErrorFlagsMask                 = 0xFFFE;          //!< HuC error 2 flags mask
     static const uint32_t m_hucFamily = 8;
 
     MHW_MEMORY_OBJECT_CONTROL_PARAMS m_cacheabilitySettings[MOS_CODEC_RESOURCE_USAGE_END_CODEC] = {};
@@ -167,9 +185,6 @@ protected:
                 this->m_osItf,
                 this->m_currentCmdBuf,
                 &resourceParams));
-
-            cmd.HucIndirectStreamInObjectbaseAttributes.DW0.Value &= MEMORY_ADDRESS_ATTRIBUTES_MOCS_CLEAN_MASK;
-            cmd.HucIndirectStreamInObjectbaseAttributes.DW0.Value |= m_cacheabilitySettings[MOS_CODEC_RESOURCE_USAGE_SURFACE_UNCACHED].Value;
         }
 
         if (!Mos_ResourceIsNull(params.StreamOutObjectBuffer))
@@ -187,10 +202,6 @@ protected:
                 this->m_osItf,
                 this->m_currentCmdBuf,
                 &resourceParams));
-
-            // base address of the stream out buffer
-            cmd.HucIndirectStreamOutObjectbaseAttributes.DW0.Value &= MEMORY_ADDRESS_ATTRIBUTES_MOCS_CLEAN_MASK;
-            cmd.HucIndirectStreamOutObjectbaseAttributes.DW0.Value |= m_cacheabilitySettings[MOS_CODEC_RESOURCE_USAGE_SURFACE_UNCACHED].Value;
         }
 
         return MOS_STATUS_SUCCESS;
@@ -255,9 +266,6 @@ protected:
 
             // set data length
             cmd.DW5.HucDataLength = params.dataLength >> MHW_VDBOX_HUC_GENERAL_STATE_SHIFT;
-
-            cmd.HucDataSourceAttributes.DW0.Value &= MEMORY_ADDRESS_ATTRIBUTES_MOCS_CLEAN_MASK;
-            cmd.HucDataSourceAttributes.DW0.Value |= m_cacheabilitySettings[MOS_CODEC_RESOURCE_USAGE_SURFACE_UNCACHED].Value;
         }
         return MOS_STATUS_SUCCESS;
     }
@@ -289,10 +297,6 @@ protected:
                     this->m_osItf,
                     this->m_currentCmdBuf,
                     &resourceParams));
-
-                cmd.HucVirtualAddressRegion[i].HucSurfaceVirtualaddrregion015.DW0.Value &= MEMORY_ADDRESS_ATTRIBUTES_MOCS_CLEAN_MASK;
-                cmd.HucVirtualAddressRegion[i].HucSurfaceVirtualaddrregion015.DW0.Value |=
-                    m_cacheabilitySettings[MOS_CODEC_RESOURCE_USAGE_HUC_VIRTUAL_ADDR_REGION_BUFFER_CODEC].Value;
             }
         }
         return MOS_STATUS_SUCCESS;
@@ -307,6 +311,7 @@ protected:
 
 #include "mhw_hwcmd_process_cmdfields.h"
     }
+MEDIA_CLASS_DEFINE_END(mhw__vdbox__huc__Impl)
 };
 }  // namespace huc
 }  // namespace vdbox
