@@ -1378,6 +1378,13 @@ MOS_STATUS MosUserSetting::InitUserSettingForDebug(MediaUserSettingSharedPtr use
         0,
         true);
 
+    DeclareUserSettingKeyForDebug(  // VP PostComp Surface Copy Dump Enable
+        userSettingPtr,
+        __VPHAL_DBG_SURF_DUMP_POSTCOMP_RESOURCE_COPY,
+        MediaUserSetting::Group::Device,
+        0,
+        true);
+
     DeclareUserSettingKeyForDebug(
         userSettingPtr,
         __MEDIA_USER_FEATURE_VALUE_SPLIT_SCREEN_DEMO_POSITION,
@@ -1427,6 +1434,13 @@ MOS_STATUS MosUserSetting::InitUserSettingForDebug(MediaUserSettingSharedPtr use
         39497,
         true); //"Device ID of mock device, default is 0x9A49"
 
+    DeclareUserSettingKeyForDebug(
+        userSettingPtr,
+        __MEDIA_USER_FEATURE_VALUE_MOCKADAPTOR_PIPE,
+        MediaUserSetting::Group::Device,
+        0,
+        true);  //"The pipe number of mock device, default is 1"
+
     //Tile resource info report
     DeclareUserSettingKeyForDebug(
         userSettingPtr,
@@ -1518,6 +1532,20 @@ MOS_STATUS MosUserSetting::InitUserSettingForDebug(MediaUserSettingSharedPtr use
         MediaUserSetting::Group::Sequence,
         uint32_t(0), // 0 chroma prefetch enabled, 1 chroma prefetch disabled ;
         false);
+
+    DeclareUserSettingKeyForDebug(
+        userSettingPtr,
+        __MEDIA_USER_FEATURE_VALUE_FORCE_ENGINE_GROUP_SCHEDULING,
+        MediaUserSetting::Group::Device,
+        0,
+        false);
+
+    DeclareUserSettingKeyForDebug(
+        userSettingPtr,
+        __MEDIA_USER_FEATURE_VALUE_FORCE_DISALBE_64BIT_TOKEN,
+        MediaUserSetting::Group::Device,
+        0,
+        false);
     return MOS_STATUS_SUCCESS;
 }
 
