@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2022, Intel Corporation
+* Copyright (c) 2022-2023, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -85,19 +85,6 @@ VAStatus DdiDecodeAv1::ParseTileParams(
         pTileCtrl++;
     }
 
-#if MOS_EVENT_TRACE_DUMP_SUPPORTED
-    if (MOS_TraceKeyEnabled(TR_KEY_DECODE_TILEPARAM))
-    {
-        CodecAv1PicParams* picAV1Params = (CodecAv1PicParams*)(m_decodeCtx->DecodeParams.m_picParams);
-
-        DECODE_EVENTDATA_TILEPARAM_AV1 eventData;
-        DECODE_EVENTDATA_TILEINFO_AV1  *pEventTileData = (DECODE_EVENTDATA_TILEINFO_AV1 *)MOS_AllocMemory(numTiles * sizeof(DECODE_EVENTDATA_TILEINFO_AV1));
-        DecodeEventDataAV1TileParamInit(&eventData, pEventTileData, picAV1Params, (CodecAv1TileParams *)(m_decodeCtx->DecodeParams.m_sliceParams), numTiles);
-        MOS_TraceEvent(EVENT_DECODE_BUFFER_TILEPARAM_AV1, EVENT_TYPE_INFO, &eventData, sizeof(eventData), pEventTileData, numTiles * sizeof(DECODE_EVENTDATA_TILEINFO_AV1));
-        MOS_FreeMemory(pEventTileData);
-    }
-#endif
-
     return VA_STATUS_SUCCESS;
 }
 
@@ -226,7 +213,10 @@ VAStatus DdiDecodeAv1::ParsePicParams(
         if (picParam->ref_frame_map[i] < mediaCtx->uiNumSurfaces)
         {
             frameIdx = GetRenderTargetID(&m_decodeCtx->RTtbl, refSurface);
-            if (frameIdx == DDI_CODEC_INVALID_FRAME_INDEX) {
+            if ((frameIdx == DDI_CODEC_INVALID_FRAME_INDEX) &&
+                (picParam->pic_info_fields.bits.frame_type != keyFrame) &&
+                (picParam->pic_info_fields.bits.frame_type != intraOnlyFrame))
+            {
                 return VA_STATUS_ERROR_INVALID_PARAMETER;
             }
             picAV1Params->m_refFrameMap[i].FrameIdx = ((uint32_t)frameIdx >= CODECHAL_NUM_UNCOMPRESSED_SURFACE_AV1) ?
@@ -470,27 +460,6 @@ VAStatus DdiDecodeAv1::ParsePicParams(
     eventData.EnabledSegment                  = picAV1Params->m_av1SegData.m_enabled;
     eventData.EnabledFilmGrain                = picAV1Params->m_seqInfoFlags.m_fields.m_filmGrainParamsPresent;
     MOS_TraceEvent(EVENT_DECODE_INFO_PICTUREVA, EVENT_TYPE_INFO, &eventData, sizeof(eventData), NULL, 0);
-
-    if (MOS_TraceKeyEnabled(TR_KEY_DECODE_PICPARAM))
-    {
-        DECODE_EVENTDATA_PICPARAM_AV1 eventData;
-        DecodeEventDataAV1PicParamInit(&eventData, picAV1Params);
-        MOS_TraceEvent(EVENT_DECODE_BUFFER_PICPARAM_AV1, EVENT_TYPE_INFO, &eventData, sizeof(eventData), NULL, 0);
-
-        if (picAV1Params->m_av1SegData.m_enabled)
-        {
-            DECODE_EVENTDATA_SEGPARAM_AV1 segEventData;
-            DecodeEventDataAV1SegParamInit(&segEventData, picAV1Params);
-            MOS_TraceEvent(EVENT_DECODE_BUFFER_SEGPARAM_AV1, EVENT_TYPE_INFO, &segEventData, sizeof(segEventData), NULL, 0);
-        }
-
-        if (picAV1Params->m_filmGrainParams.m_filmGrainInfoFlags.m_fields.m_applyGrain)
-        {
-            DECODE_EVENTDATA_FILMGRAINPARAM_AV1 filmGrainEventData;
-            DecodeEventDataAV1FilmGrainParamInit(&filmGrainEventData, picAV1Params);
-            MOS_TraceEvent(EVENT_DECODE_BUFFER_FILMGRAINPARAM_AV1, EVENT_TYPE_INFO, &filmGrainEventData, sizeof(filmGrainEventData), NULL, 0);
-        }
-    }
 #endif
 
     return VA_STATUS_SUCCESS;
@@ -501,6 +470,7 @@ VAStatus DdiDecodeAv1::SetDecodeParams()
     DDI_CODEC_FUNC_ENTER;
 
      DDI_CHK_RET(DdiDecodeBase::SetDecodeParams(),"SetDecodeParams failed!");
+
 #ifdef _DECODE_PROCESSING_SUPPORTED
     // Bridge the SFC input with vdbox output
     if (m_decProcessingType == VA_DEC_PROCESSING)
@@ -622,32 +592,6 @@ VAStatus DdiDecodeAv1::RenderPicture(
                                               &m_decodeCtx->BufMgr.resBitstreamBuffer);
             m_decodeCtx->DecodeParams.m_dataSize += dataSize;
 
-#if MOS_EVENT_TRACE_DUMP_SUPPORTED
-            uint8_t * pDataBuf = (uint8_t *)MediaLibvaUtilNext::LockBuffer(m_decodeCtx->BufMgr.pBitStreamBuffObject[index], MOS_LOCKFLAG_READONLY);            
-            DDI_CODEC_CHK_NULL(pDataBuf, "nullptr bitstream", VA_STATUS_ERROR_INVALID_BUFFER);
-
-            if (MOS_TraceKeyEnabled(TR_KEY_DECODE_BITSTREAM_INFO))
-            {
-                DECODE_EVENTDATA_BITSTREAM eventData;
-                for (int i = 0; i < 32; i++)
-                {
-                    eventData.Data[i] = pDataBuf[i];
-                }
-                MOS_TraceEvent(EVENT_DECODE_INFO_BITSTREAM, EVENT_TYPE_INFO, &eventData, sizeof(eventData), NULL, 0);
-            }
-
-            if (MOS_TraceKeyEnabled(TR_KEY_DECODE_BITSTREAM))
-            {
-                MOS_TraceDataDump(
-                "Decode_Bitstream",
-                0,
-                pDataBuf,
-                m_decodeCtx->DecodeParams.m_dataSize);
-            }
-                
-            MediaLibvaUtilNext::UnlockBuffer(m_decodeCtx->BufMgr.pBitStreamBuffObject[index]);
-#endif
-
             break;
         }
         case VASliceParameterBufferType:
@@ -670,10 +614,9 @@ VAStatus DdiDecodeAv1::RenderPicture(
             DDI_CHK_RET(ParsePicParams(mediaCtx, picParam), "ParsePicParams failed!");
             break;
         }
-
         case VAProcPipelineParameterBufferType:
         {
-            DDI_CODEC_NORMALMESSAGE("ProcPipeline is not supported for AV1 decoding\n");
+            DDI_CHK_RET(ParseProcessingBuffer(mediaCtx, data),"ParseProcessingBuffer failed!");
             break;
         }
         case VADecodeStreamoutBufferType:
@@ -871,7 +814,7 @@ VAStatus DdiDecodeAv1::CodecHalInit(
     m_codechalSettings->intelEntrypointInUse = false;
 
     // VAProfileAV1Profile0 supports both 420 8bit and 420 10bit
-    m_codechalSettings->lumaChromaDepth = CODECHAL_LUMA_CHROMA_DEPTH_8_BITS | CODECHAL_LUMA_CHROMA_DEPTH_10_BITS;
+    m_codechalSettings->lumaChromaDepth = CODECHAL_LUMA_CHROMA_DEPTH_8_BITS;
 
     m_codechalSettings->shortFormatInUse = m_decodeCtx->bShortFormatInUse;
 
@@ -894,6 +837,31 @@ VAStatus DdiDecodeAv1::CodecHalInit(
         return vaStatus;
     }
 
+#ifdef _DECODE_PROCESSING_SUPPORTED
+    if (m_decProcessingType == VA_DEC_PROCESSING)
+    {
+        DecodeProcessingParams *procParams = nullptr;
+
+        m_codechalSettings->downsamplingHinted = true;
+
+        procParams = (DecodeProcessingParams *)MOS_AllocAndZeroMemory(sizeof(DecodeProcessingParams));
+        if (procParams == nullptr)
+        {
+            vaStatus = VA_STATUS_ERROR_ALLOCATION_FAILED;
+            FreeResource();
+            return vaStatus;
+        }
+
+        m_decodeCtx->DecodeParams.m_procParams = procParams;
+        procParams->m_outputSurface = (PMOS_SURFACE)MOS_AllocAndZeroMemory(sizeof(MOS_SURFACE));
+        if (procParams->m_outputSurface == nullptr)
+        {
+            vaStatus = VA_STATUS_ERROR_ALLOCATION_FAILED;
+            FreeResource();
+            return vaStatus;
+        }
+    }
+#endif
     vaStatus = CreateCodecHal(mediaCtx,
         ptr,
         &standardInfo);
@@ -932,6 +900,15 @@ void DdiDecodeAv1::FreeResource()
     MOS_FreeMemory(m_decodeCtx->DecodeParams.m_sliceParams);
     m_decodeCtx->DecodeParams.m_sliceParams = nullptr;
 
+#ifdef _DECODE_PROCESSING_SUPPORTED
+    if (m_decodeCtx->DecodeParams.m_procParams)
+    {
+        auto procParams = (DecodeProcessingParams *)m_decodeCtx->DecodeParams.m_procParams;
+        MOS_FreeMemory(procParams->m_outputSurface);
+
+        MOS_FreeMemory(m_decodeCtx->DecodeParams.m_procParams);
+    }
+#endif
     return;
 }
 
@@ -1029,51 +1006,4 @@ void DdiDecodeAv1::ContextInit(
     return;
 }
 
-VAStatus DdiDecodeAv1::CheckDecodeResolution(
-    int32_t   codecMode,
-    VAProfile profile,
-    uint32_t  width,
-    uint32_t  height)
-{
-    DDI_CODEC_FUNC_ENTER;
-
-    uint32_t maxWidth = 0, maxHeight = 0;
-    switch (codecMode)
-    {
-    case CODECHAL_DECODE_MODE_AV1VLD:
-        maxWidth  = m_decAv1Max16kWidth;
-        maxHeight = m_decAv1Max16kHeight;
-        break;
-    default:
-        maxWidth  = m_decDefaultMaxWidth;
-        maxHeight = m_decDefaultMaxHeight;
-        break;
-    }
-
-    if (width > maxWidth || height > maxHeight)
-    {
-        return VA_STATUS_ERROR_RESOLUTION_NOT_SUPPORTED;
-    }
-    else
-    {
-        return VA_STATUS_SUCCESS;
-    }
-}
-
-CODECHAL_MODE DdiDecodeAv1::GetDecodeCodecMode(VAProfile profile)
-{
-    DDI_CODEC_FUNC_ENTER;
-
-    int8_t vaProfile = (int8_t)profile;
-    switch (vaProfile)
-    {
-    case VAProfileAV1Profile0:
-    case VAProfileAV1Profile1:
-        return CODECHAL_DECODE_MODE_AV1VLD;
-    default:
-        DDI_CODEC_ASSERTMESSAGE("Invalid Decode Mode");
-        return CODECHAL_UNSUPPORTED_MODE;
-    }
-}
-
 } // namespace decode
